// Load historical temperature data from JSON file
const temperature = require('./temperature.json');

// Temporary security setting for development - allow self-signed certificates
process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';

// Configure Elasticsearch connection parameters
const https = require('https');
const options = {
  hostname: 'localhost',
  port: 9200,
  path: '/temperatures/_doc',  // Target Elasticsearch index and document type
  method: 'POST',
  headers: {
    'Content-Type': 'application/json'
  },
  auth: 'elastic:elastic'  // Basic authentication credentials
};

// Process each temperature record and index in Elasticsearch
Object.entries(temperature).forEach(([date, temp]) => {
  // Create HTTP request for each document
  const req = https.request(options, (res) => {
    console.log(`Indexed document - Status: ${res.statusCode}`);
    res.on('data', (d) => {
      process.stdout.write(d);
    });
  });

  // Handle request errors
  req.on('error', (error) => {
    console.error(`Failed to index ${date}:`, error);
  });

  // Create document body with timestamp and temperature
  req.write(JSON.stringify({
    date: date,          // ISO date string
    temperature: temp    // Temperature in degrees Celsius
  }));
  
  req.end();
});


