from elasticsearch8 import Elasticsearch
import pandas as pd
import scipy as sc
import numpy as np
from typing import Optional


def main() -> str:
    """Verifies core analytics library versions and Elasticsearch connectivity.

    Returns:
        str: Formatted string containing versions of:
        - ElasticSearch cluster
        - SciPy
        - NumPy

    Raises:
        elasticsearch.ElasticsearchException: For ES connection failures

    Note:
        Primarily used for dependency compatibility checks during deployments

    Security Note:
        Disables certificate verification (verify_certs=False) for internal cluster
        communication - not recommended for production use
    """
    client: Elasticsearch = Elasticsearch(
        'https://elasticsearch-master.elastic.svc.cluster.local:9200',
        verify_certs=False,
        ssl_show_warn=False,
        basic_auth=('elastic', 'elastic')
    )

    return (
        f'ElasticSearch: {client.info()["version"]["number"]}\n'
        f'SciPy: {sc.__version__}\n'
        f'NumPy: {np.version.version}\n'
    )
