from typing import Tuple

class Commons:
    """Provides common configuration and Elasticsearch utility methods.

    This class contains static methods for:
    - Reading configuration parameters
    - Generating Elasticsearch authentication credentials
    - Building Elasticsearch API endpoints
    """

    @staticmethod
    def config(k: str) -> str:
        """Read a configuration parameter from default configmap.

        Args:
            k: Configuration key (filename without extension)

        Returns:
            Contents of the configuration file as string

        Raises:
            IOError: If the configuration file cannot be found or read
        """
        with open(f'/configs/default/parameters/{k}', 'r') as f:
            return f.read()

    @staticmethod
    def auth() -> Tuple[str, str]:
        """Get Elasticsearch authentication credentials.

        Returns:
            Tuple containing:
            - Elasticsearch username
            - Elasticsearch password
        """
        return (Commons.config("ES_USERNAME"), Commons.config("ES_PASSWORD"))

    @staticmethod
    def search_url() -> str:
        """Build Elasticsearch search API endpoint URL.

        Combines base URL and database name from configuration.

        Returns:
            Complete search API URL string
        """
        return f'{Commons.config("ES_URL")}/{Commons.config("ES_DATABASE")}/_search'
