from flask import Request
from typing import Tuple, Dict, Any
from Commons import Commons
from ESStudent import ESStudent

def main(request: Request) -> Tuple[Dict[str, Any], int]:
    """Retrieve all student documents from Elasticsearch.

    Args:
        request: Flask request object containing optional query parameters

    Returns:
        Tuple containing:
        - List of student documents (JSON format)
        - HTTP status code

    Example:
        GET /students?department=computer_science
    """
    try:
        commons = Commons()
        es_student = ESStudent(commons, request)
        
        # Execute search
        response = requests.post(
            commons.search_url(),
            verify=False,
            auth=commons.auth(),
            headers={'Content-Type': 'application/json'},
            data=es_student.all()
        )
        
        return response.json(), response.status_code
    
    except Exception as e:
        current_app.logger.error(f"Failed to retrieve students: {str(e)}")
        return {"error": "Internal server error"}, 500
